# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


package Scmbug::Glue::Git;

@ISA = qw ( Scmbug::Glue::SCM );

use strict;
use Data::Dumper;
use Env qw( USER CVS_USER USERNAME );
use Scmbug::Activity;
use Scmbug::Error;
use Scmbug::Glue::SCM;



use Scmbug::Common qw (
				     scmbug_error
				     notify
				     execute_command
				     
				     $TAG_OPERATION_ADD
				     $TAG_OPERATION_DELETE
				     $TAG_OPERATION_MOVE
				     );
use vars qw (
	     $TAG_OPERATION_ADD
	     $TAG_OPERATION_DELETE
	     $TAG_OPERATION_MOVE
	     );

# Constructor
sub new {
    my $type = shift;
    my $data = shift;
    my $self = Scmbug::Glue::SCM->new( $data );

    bless $self, $type;

    # REVISE:
    # Identify the username of the Git user
    if ( defined ( $USER ) ) {
	$self->user( $USER );
    } else {
	$self->user( $USERNAME );
    }

    return $self;
}



sub detect_version {
    my $self = shift;
    my $command = "git --version";
    my $command_output = execute_command($command);

    my $version = $command_output;
    $version =~ s/.*?(\d+\.\d+\.\d+).*/$1/s;

    $self->version( $version );
}


# Initializes some internal configuration parameters
sub init_internal {
    my $self = shift;

    $self->required_tool("git");
}


sub set_version_type {
    my $self = shift;
    my $version = $self->version();

    if ($version =~ m/(\d+)\.(\d+)\.(\d+)/ ) {
	my $major = $1;
	my $minor = $2;
	my $patch = $3;
	if ( $major == 1 ) {
	    if ( $minor == 5 ) {
		$self->version_type( $SCM_VERSION_LATEST );
	    } else {
		$self->version_type( $SCM_VERSION_NOT_SUPPORTED );
	    }
	} else {
	    $self->version_type( $SCM_VERSION_NOT_SUPPORTED );
	}
    } else {
	$self->version_type( $SCM_VERSION_WRONG_FORMAT );
    }
}



#
# Prepares the internal data structures to handle a verification
# activity using data received from CVS
#
sub prepare_activity_verify() {
    my $self = shift;
    my $log_message_file = shift;
    my $line;

    # REVISE:
    # It is impossible to determine the branch name from Git at this
    # stage
    $self->activity()->branch_name( $BRANCH_NAME_INDETERMINATE );

    # These are the arguments produced by Git
    # There is only 1 and it is in the format: <log_file_name>
    open ( LOG_MESSAGE_FILE, "< $log_message_file" );
    my $message = "";
    while ( $line = <LOG_MESSAGE_FILE> ) {
	$message .= $line;
    }
    $self->activity()->original_log_message( $message );
    close ( LOG_MESSAGE_FILE );
}




#
# Prepares the internal data structures to handle a commit activity
# using data received from Git
#
sub prepare_activity_commit {
    my $self = shift;
    my ( @remaining_arguments ) = ( @_ );

}



#
# Prepares the internal data structures to handle a tagging activity
# using data received from CVS
#
sub prepare_activity_tag {
    my $self = shift;
    my ( @arguments ) = ( @_ );

}



#
# Used to detect the branch name.
#
sub prepare_branch_name {
    my $self = shift;
}



1;
